Welcome to Brownie!
===================

- Have you ever started a new project and implemented this little function
  foo or this datastructure bar you already implemented for another project?
- Ever wondered why a specific feature is not in the `standard library`_
  already?
- Wanted to use that new datastructure but you are still stuck with this
  ancient Python version or are just not willing or able to switch to
  Python 3.x, yet?
- And most importantly were too lazy to implement this datastructure which
  would be more appropriate to use?

Brownie wants to solve these problems by providing all these small things
well documented, well tested and most importantly right now when you need
it.

Take a look at the documentation_ for further information, visit Github_
for development or issue tracking or fetch the `latest development version`_.

.. _standard library: http://docs.python.org/library
.. _documentation: http://packages.python.org/Brownie
.. _Github: http://github.com/DasIch/Brownie
.. _latest development version: https://github.com/DasIch/brownie/zipball/master#egg=Brownie-dev

Installation
------------

Brownie runs on Python 2.5-2.7 (tested on CPython_ and PyPy_). In order to
install it simply run ``pip install brownie`` or ``easy_install brownie``,
should you prefer the latter, to get the latest stable version.

If you really need to, you can also install the development version of
Brownie with ``pip install brownie==dev``. However I do not recommend it.

.. _CPython: http://python.org
.. _PyPy: http://pypy.org


Development
-----------

Should you want to participate in the development, fork the repository on
Github_ and take a moment to read :ref:`contributing`, for a couple of
general and not so general guidelines you should follow.
